@@ -10,7 +10,7 @@ use Moo;
 with "Dancer2::Plugin::Auth::Extensible::Role::Provider";
 use namespace::clean;
 
-our $VERSION = '0.600';
+our $VERSION = '0.601';
 
 =head1 NAME 
 
@@ -468,7 +468,7 @@ sub _user_rset {
 
     # Search based on standard username search, plus any additional
     # conditions in ignore_user
-    my $search = { %$user_valid_conditions, $search_column => $value };
+    my $search = { %$user_valid_conditions, 'me.' . $search_column => $value };
 
     # Look up the user
     $self->schema->resultset($self->users_resultset)->search($search, $options);
